==> haskell-th-desugar-1.11-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-desugar
version:              1.11
visibility:           public
id:                   th-desugar-1.11-38BjXctlRwO1k72r9bSEP2
key:                  th-desugar-1.11-38BjXctlRwO1k72r9bSEP2
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Richard Eisenberg <rae@cs.brynmawr.edu>
stability:            experimental
homepage:             https://github.com/goldfirere/th-desugar
synopsis:             Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.

category:             Template Haskell
abi:                  51ffe3f1abcca6d6c6396098a718e4de
exposed:              True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.OMap
    Language.Haskell.TH.Desugar.OMap.Strict
    Language.Haskell.TH.Desugar.OSet Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten

hidden-modules:
    Language.Haskell.TH.Desugar.AST Language.Haskell.TH.Desugar.Core
    Language.Haskell.TH.Desugar.FV Language.Haskell.TH.Desugar.Match
    Language.Haskell.TH.Desugar.Reify Language.Haskell.TH.Desugar.Util

import-dirs:          /usr/lib/ghc-8.10.1/site-local/th-desugar-1.11
library-dirs:         /usr/lib/ghc-8.10.1/site-local/th-desugar-1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/th-desugar-1.11
hs-libraries:         HSth-desugar-1.11-38BjXctlRwO1k72r9bSEP2
depends:
    base-4.14.0.0 containers-0.6.2.1 ghc-prim-0.6.1 mtl-2.2.2
    ordered-containers-0.2.2-D5PYd4TLQJmiuljuJOQK3
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K template-haskell-2.16.0.0
    th-abstraction-0.3.2.0-4yEKsz3hkum2d9EYr8unnF
    th-lift-0.8.1-BllvzgsbE8XFqTlJuRRkNs
    th-orphans-0.13.10-BNXrMeFfljV9gbKpv0eCHH
    transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi

haddock-interfaces:   /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html:         /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-desugar-1.11-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-desugar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-desugar
version:              1.11
visibility:           public
id:                   th-desugar-1.11-FIDORT93NO6AsPC64M7E8f
key:                  th-desugar-1.11-FIDORT93NO6AsPC64M7E8f
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Richard Eisenberg <rae@cs.brynmawr.edu>
stability:            experimental
homepage:             https://github.com/goldfirere/th-desugar
synopsis:             Functions to desugar Template Haskell
description:
    This package provides the Language.Haskell.TH.Desugar module, which desugars
    Template Haskell'\''s rich encoding of Haskell syntax into a simpler encoding.
    This desugaring discards surface syntax information (such as the use of infix
    operators) but retains the original meaning of the TH code. The intended use
    of this package is as a preprocessor for more advanced code manipulation
    tools. Note that the input to any of the ds... functions should be produced
    from a TH quote, using the syntax [| ... |]. If the input to these functions
    is a hand-coded TH syntax tree, the results may be unpredictable. In
    particular, it is likely that promoted datatypes will not work as expected.

category:             Template Haskell
abi:                  c70b7274a5789e5ea3d5f771e02f0ef2
exposed:              True
exposed-modules:
    Language.Haskell.TH.Desugar Language.Haskell.TH.Desugar.Expand
    Language.Haskell.TH.Desugar.Lift Language.Haskell.TH.Desugar.OMap
    Language.Haskell.TH.Desugar.OMap.Strict
    Language.Haskell.TH.Desugar.OSet Language.Haskell.TH.Desugar.Subst
    Language.Haskell.TH.Desugar.Sweeten

hidden-modules:
    Language.Haskell.TH.Desugar.AST Language.Haskell.TH.Desugar.Core
    Language.Haskell.TH.Desugar.FV Language.Haskell.TH.Desugar.Match
    Language.Haskell.TH.Desugar.Reify Language.Haskell.TH.Desugar.Util

import-dirs:          /usr/lib/ghc-8.10.1/site-local/th-desugar-1.11
library-dirs:         /usr/lib/ghc-8.10.1/site-local/th-desugar-1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/th-desugar-1.11
hs-libraries:         HSth-desugar-1.11-FIDORT93NO6AsPC64M7E8f
depends:
    base-4.14.0.0 containers-0.6.2.1 ghc-prim-0.6.1 mtl-2.2.2
    ordered-containers-0.2.2-D5PYd4TLQJmiuljuJOQK3
    syb-0.7.1-6kfNxsXCCuQCrpdoMzyi8K template-haskell-2.16.0.0
    th-abstraction-0.3.2.0-4yEKsz3hkum2d9EYr8unnF
    th-lift-0.8.1-BllvzgsbE8XFqTlJuRRkNs
    th-orphans-0.13.10-4GWni1VUbVwJ2K5gFoeHnj
    transformers-compat-0.6.5-5FpQwDSHwAD8xLwpEoaQi

haddock-interfaces:   /usr/share/doc/haskell-th-desugar/html/th-desugar.haddock
haddock-html:         /usr/share/doc/haskell-th-desugar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
